@@ -48,12 +48,12 @@ except:
     gpod_available = False
     logger.warning('Could not find gpod')
 
-#pymtp_available = True
-#try:
-#    import gpodder.gpopymtp as pymtp
-#except:
-#    pymtp_available = False
-#    logger.warning('Could not load gpopymtp (libmtp not installed?).')
+# pymtp_available = True
+# try:
+#     import gpodder.gpopymtp as pymtp
+# except:
+#     pymtp_available = False
+#     logger.warning('Could not load gpopymtp (libmtp not installed?).')
 
 try:
     import eyed3.mp3
@@ -129,7 +129,7 @@ def get_track_length(filename):
     if util.find_command('mplayer') is not None:
         try:
             mplayer_output = os.popen('mplayer -msglevel all=-1 -identify -vo null -ao null -frames 0 "%s" 2>/dev/null' % filename).read()
-            return int(float(mplayer_output[mplayer_output.index('ID_LENGTH'):].splitlines()[0][10:])*1000)
+            return int(float(mplayer_output[mplayer_output.index('ID_LENGTH'):].splitlines()[0][10:]) * 1000)
         except:
             pass
     else:
@@ -141,7 +141,8 @@ def get_track_length(filename):
     except Exception as e:
         logger.warn('Could not determine length: %s', filename, exc_info=True)
 
-    return int(60*60*1000*3) # Default is three hours (to be on the safe side)
+    return int(60 * 60 * 1000 * 3)
+    # Default is three hours (to be on the safe side)
 
 
 class SyncTrack(object):
@@ -224,10 +225,10 @@ class Device(services.ObservableService):
                     return False
 
                 # XXX: need to check if track is added properly?
-                sync_task=SyncTask(track)
+                sync_task = SyncTask(track)
 
-                sync_task.status=sync_task.QUEUED
-                sync_task.device=self
+                sync_task.status = sync_task.QUEUED
+                sync_task.device = self
                 # New Task, we must wait on the GTK Loop
                 self.download_status_model.register_task(sync_task)
                 # Executes after task has been registered
@@ -284,7 +285,7 @@ class iPodDevice(Device):
 
     def get_free_space(self):
         # Reserve 10 MiB for iTunesDB writing (to be on the safe side)
-        RESERVED_FOR_ITDB = 1024*1024*10
+        RESERVED_FOR_ITDB = 1024 * 1024 * 10
         result = util.get_free_disk_space(self.mountpoint)
         if result == -1:
             # Can't get free disk space
@@ -415,7 +416,7 @@ class iPodDevice(Device):
     def add_track(self, episode,reporthook=None):
         self.notify('status', _('Adding %s') % episode.title)
         tracklist = gpod.sw_get_playlist_tracks(self.podcasts_playlist)
-        podcasturls=[track.podcasturl for track in tracklist]
+        podcasturls = [track.podcasturl for track in tracklist]
 
         if episode.url in podcasturls:
             # Mark as played on iPod if played locally (and set podcast flags)
@@ -431,7 +432,7 @@ class iPodDevice(Device):
         if util.calculate_size(original_filename) > self.get_free_space():
             logger.error('Not enough space on %s, sync aborted...', self.mountpoint)
             d = {'episode': episode.title, 'mountpoint': self.mountpoint}
-            message =_('Error copying %(episode)s: Not enough free space on %(mountpoint)s')
+            message = _('Error copying %(episode)s: Not enough free space on %(mountpoint)s')
             self.errors.append(message % d)
             self.cancelled = True
             return False
@@ -507,7 +508,7 @@ class MP3PlayerDevice(Device):
             download_queue_manager):
         Device.__init__(self, config)
         self.destination = self._config.device_sync.device_folder
-        self.buffer_size = 1024*1024 # 1 MiB
+        self.buffer_size = 1024 * 1024  # 1 MiB
         self.download_status_model = download_status_model
         self.download_queue_manager = download_queue_manager
 
@@ -577,7 +578,7 @@ class MP3PlayerDevice(Device):
             logger.warn('Cannot determine free disk space on device')
         elif needed > free:
             d = {'path': self.destination, 'free': util.format_filesize(free), 'need': util.format_filesize(needed)}
-            message =_('Not enough space in %(path)s: %(free)s available, but need at least %(need)s')
+            message = _('Not enough space in %(path)s: %(free)s available, but need at least %(need)s')
             raise SyncFailedException(message % d)
 
         # get the filename that will be used on the device
@@ -634,7 +635,7 @@ class MP3PlayerDevice(Device):
                     pass
                 try:
                     logger.info('Trying to remove partially copied file: %s' % to_file)
-                    os.unlink( to_file)
+                    os.unlink(to_file)
                     logger.info('Yeah! Unlinked %s at least..' % to_file)
                 except:
                     logger.error('Error while trying to unlink %s. OH MY!' % to_file)
@@ -693,7 +694,7 @@ class MP3PlayerDevice(Device):
     def directory_is_empty(self, directory):
         files = glob.glob(os.path.join(directory, '*'))
         dotfiles = glob.glob(os.path.join(directory, '.*'))
-        return len(files+dotfiles) == 0
+        return len(files + dotfiles) == 0
 
 
 class MTPDevice(Device):
@@ -710,7 +711,7 @@ class MTPDevice(Device):
     def __callback(self, sent, total):
         if self.cancelled:
             return -1
-        percentage = round(sent/total*100)
+        percentage = round(sent / total * 100)
         text = ('%i%%' % percentage)
         self.notify('progress', sent, total, text)
 
@@ -741,13 +742,14 @@ class MTPDevice(Device):
             return None
 
         try:
-            mtp = mtp.replace(" ", "0") # replace blank with 0 to fix some invalid string
+            mtp = mtp.replace(" ", "0")
+            # replace blank with 0 to fix some invalid string
             d = time.strptime(mtp[:8] + mtp[9:13],"%Y%m%d%H%M%S")
             _date = calendar.timegm(d)
-            if len(mtp)==20:
+            if len(mtp) == 20:
                 # TIME ZONE SHIFTING: the string contains a hour/min shift relative to a time zone
                 try:
-                    shift_direction=mtp[15]
+                    shift_direction = mtp[15]
                     hour_shift = int(mtp[16:18])
                     minute_shift = int(mtp[18:20])
                     shift_in_sec = hour_shift * 3600 + minute_shift * 60
@@ -759,7 +761,7 @@ class MTPDevice(Device):
                         raise ValueError("Expected + or -")
                 except Exception as exc:
                     logger.warning('WARNING: ignoring invalid time zone information for %s (%s)')
-            return max( 0, _date )
+            return max(0, _date)
         except Exception as exc:
             logger.warning('WARNING: the mtp date "%s" can not be parsed against mtp specification (%s)')
             return None
@@ -784,7 +786,8 @@ class MTPDevice(Device):
         if self.__MTPDevice is None:
             return _('MTP device')
 
-        self.__model_name = self.__MTPDevice.get_devicename() # actually libmtp.Get_Friendlyname
+        self.__model_name = self.__MTPDevice.get_devicename()
+        # actually libmtp.Get_Friendlyname
         if not self.__model_name or self.__model_name == "?????":
             self.__model_name = self.__MTPDevice.get_modelname()
         if not self.__model_name:
@@ -895,7 +898,7 @@ class MTPDevice(Device):
         tracks = []
         for track in listing:
             title = track.title
-            if not title or title=="": title=track.filename
+            if not title or title == "": title = track.filename
             if len(title) > 50: title = title[0:49] + '...'
             artist = track.artist
             if artist and len(artist) > 50: artist = artist[0:49] + '...'
@@ -903,8 +906,8 @@ class MTPDevice(Device):
             age_in_days = 0
             date = self.__mtp_to_date(track.date)
             if not date:
-                modified = track.date # not a valid mtp date. Display what mtp gave anyway
-                modified_sort = -1 # no idea how to sort invalid date
+                modified = track.date  # not a valid mtp date. Display what mtp gave anyway
+                modified_sort = -1  # no idea how to sort invalid date
             else:
                 modified = util.format_date(date)
                 modified_sort = date
@@ -1048,7 +1051,7 @@ class SyncTask(download.DownloadTask):
             self.total_size = float(totalSize)
 
         if self.total_size > 0:
-            self.progress = max(0.0, min(1.0, (count*blockSize)/self.total_size))
+            self.progress = max(0.0, min(1.0, (count * blockSize) / self.total_size))
             self._progress_updated(self.progress)
 
         if self.status == SyncTask.CANCELLED:
@@ -1102,4 +1105,3 @@ class SyncTask(download.DownloadTask):
 
         # We finished, but not successfully (at least not really)
         return False
-
